==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Line/LineRelativeAngle/ts/LineRelativeAngle_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>LineRelativeAngle</name>
    <message>
        <source>Choose base entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz jednostkę bazową</translation>
    </message>
    <message>
        <location filename="../LineRelativeAngle.js" line="+70"/>
        <source>Choose base line, arc, circle, ellipse or polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Set position</source>
        <translatorcomment>--google--
Zmień pozycje punktu zera względnego
Ustaw pozycję punktu zera względnego</translatorcomment>
        <translation type="unfinished">Ustaw pozycję</translation>
    </message>
    <message>
        <location filename="../LineRelativeAngle.ui" line="+17"/>
        <source>Relative Angle:</source>
        <translatorcomment>--ignored colon--
--file: qcadactions_pl.ts--</translatorcomment>
        <translation type="unfinished">Kąt względny:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Length:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź długość cięciwy:
Wprowadź długość:</translatorcomment>
        <translation type="unfinished">Długość:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Reference Point:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Middle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../LineRelativeAngleInit.js" line="+2"/>
        <source>R&amp;elative Angle</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Kąt wz&amp;ględny</translatorcomment>
        <translation type="unfinished">Kąt wz&amp;ględny</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw line with relative angle to base entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narysuj linię z względnym kątem do jednostki bazowej</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Line/LineRelativeAngle/ts/LineRelativeAngle_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LineRelativeAngle</name>
    <message>
        <source>Choose base entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz jednostkę bazową</translation>
    </message>
    <message>
        <location filename="../LineRelativeAngle.js" line="+70"/>
        <source>Choose base line, arc, circle, ellipse or polyline</source>
        <translation>Proszę wskazać linię, łuk, okrąg, elipsę lub linię łamaną</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Set position</source>
        <translatorcomment>--google--
Zmień pozycje punktu zera względnego
Ustaw pozycję punktu zera względnego</translatorcomment>
        <translation>Proszę wskazać położenie</translation>
    </message>
    <message>
        <location filename="../LineRelativeAngle.ui" line="+17"/>
        <source>Relative Angle:</source>
        <translatorcomment>--ignored colon--
--file: qcadactions_pl.ts--</translatorcomment>
        <translation>Kąt względny:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Length:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź długość cięciwy:
Wprowadź długość:</translatorcomment>
        <translation>Długość:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Reference Point:</source>
        <translation>Punkt &amp;odniesienia:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Start</source>
        <translation>Początek</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Middle</source>
        <translation>Środek</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>End</source>
        <translation>Koniec</translation>
    </message>
    <message>
        <location filename="../LineRelativeAngleInit.js" line="+2"/>
        <source>R&amp;elative Angle</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Kąt wz&amp;ględny</translatorcomment>
        <translation>Kąt w&amp;zględny</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw line with relative angle to base entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje linię pod kątem, względem wskazanego obiektu</translation>
    </message>
</context>
</TS>
